@@ -51,17 +51,18 @@ void FirebaseRemoteConfig::release()
 
 json FirebaseRemoteConfig::Preprocess(const char* key)
 {
-	std::vector<std::string> steps = split(key, '/');
+	std::vector<std::string> steps = split(key, '.');
 
 	remote_config::ValueInfo value_info;
 	auto result = remote_config::GetString(steps[0].c_str(), &value_info);
+	if (result.empty() || result == "null")	return "";
 
 	json result_json;
 	std::stringstream(result) >> result_json;
 
 	for (int i = 1; i < steps.size() ; i++)
 	{
-		if (result.empty() || result == "null")	return nullptr;
+		if (result.empty() || result == "null")	return "";
 		result_json = result_json[steps[i]];
 	}
 
